@@ -2,7 +2,7 @@
 from typing import List
 
 from okdmr.kaitai.etsi.dmr_csbk import DmrCsbk
-from okdmr.tests.tests_utils import prettyprint
+from okdmr.tests.kaitai.tests_utils import prettyprint
 
 
 def test_csbk_hex():
